Remove warning on ballot/any/all and pop/clz.

Since these are supported in HIP no reason to emit warnings.


[ROCm/clr commit: 182296ce59]
Bu işleme şunda yer alıyor:
Ben Sander
2016-02-02 10:02:48 -06:00
ebeveyn 94863d2bee
işleme 71bfa20508
3 değiştirilmiş dosya ile 29 ekleme ve 5 silme
+5 -5
Dosyayı Görüntüle
@@ -624,12 +624,12 @@ sub warnUnsupportedSpecialFunctions
"__ldg",
# Cross-lane and warp-vote instructions:
"__all",
"__any",
"__ballot",
#"__all",
#"__any",
#"__ballot",
"__popc",
"__clz",
#"__popc",
#"__clz",
"__shfl",
"__shfl_up",
+13
Dosyayı Görüntüle
@@ -75,6 +75,7 @@ macro (make_hip_executable exe cpp)
endif()
endmacro()
macro (make_test exe )
string (REPLACE " " "" smush_args ${ARGN})
set (testname ${exe}${smush_args}.tst)
@@ -87,6 +88,16 @@ macro (make_test exe )
endmacro()
macro (make_hipify_test sourceFile )
#string (REPLACE " " "" smush_args ${ARGN})
set (testname ${sourceFile}${smush_args}.tst)
add_test (NAME ${testname}
COMMAND ${HIP_PATH}/bin/hipify ${PROJECT_SOURCE_DIR}/${sourceFile} ${ARGN}
)
endmacro()
macro (make_test_matches exe match_string)
string (REPLACE " " "" smush_args ${ARGN})
set (testname ${exe}${smush_args}.tst)
@@ -133,3 +144,5 @@ make_test(hipGridLaunch " " )
make_test(hipMemcpy " " )
make_test(hipHcc " " )
make_hipify_test(specialFunc.cu )
+11
Dosyayı Görüntüle
@@ -0,0 +1,11 @@
//Test to ensure hipify runs correctly.
// Hipify may report warnings for some missing/unsupported functions
void __global__
test_kernel(float *A)
{
int tid = blockIdx.x * blockDim.x + threadIdx.x;
float a = __ballot(tid < 16);
float b = __shfl(tid < 16);
}